Learn R Programming

varjmcm (version 0.1.1)

bootcovjmcm: Estimate the covariance of estimated parameters using a bootstrap based method

Description

bootcovjmcm gives the estimation of the covariance of estimated parameters returned by jmcm by using a bootstrap based method.

Usage

bootcovjmcm(object, mydata, numboot)

Arguments

object

a fitted joint mean-covariance model of class "jmcmMod", returned by the function jmcm.

mydata

the data frame used in fitting the model.

numboot

the number of the bootstrap replications

Value

an estimated covariance matrix of the estimated parameters.

References

[1] Liu, R.Y. (1988) "Bootstrap Procedure under Some Non-i.i.d. Models." Annals of Statistics, 16, 1696-1708.

Examples

Run this code
# NOT RUN {
cattleA <- cattle[cattle$group=='A', ]
fit.mcd <- jmcm(weight|id|I(ceiling(day/14+1))~1|1,
               data = cattleA,
               cov.method = "mcd",
               triple = c(1,1,1))
bootcovjmcm(fit.mcd, cattleA, 5)
## Larger number of replications is needed to achieve accuracy,
## however it may take hours.
# }
# NOT RUN {
bootcovjmcm(fit.mcd, cattleA, 500)
# }

Run the code above in your browser using DataLab